Config

Struct Config 

pub struct Config {
    pub persister: String,
    pub force_drop: bool,
    pub force_copy: bool,
    pub drop_after_copy: bool,
}
Contains the configuration used while running postit.

If the configuration file doesn’t exist, it uses the default values defined in the Default trait implementation.

Fields

persister: String

Defines where tasks are stored. It can be the path to a file or a database connection string (including protocol).

force_drop: bool

If true, allows dropping tasks without them being checked.

force_copy: bool

If true, allows overwriting files if they already exist.

drop_after_copy: bool

If true, drops the old file after copying its contents to the new file.

Implementations

Source

impl Config

pub fn manage(subcommand: Config) -> Result<()>

Manages the .postit.toml file using a ConfigSubcommand instance.

Errors
  • Any error while doing operations on a the configuration file.
pub fn init() -> Result<()>

Creates the config file from the default values.

Errors
  • The path can’t be obtained.
  • The config file already exists at the used path.
pub fn print_env() -> Result<()>

Prints the value of the POSTIT_ROOT env var.

Errors
  • The POSTIT_ROOT exists but is empty.
pub fn print_path() -> Result<()>

Prints the path of the config file.

Errors
  • The file doesn’t exist at the parent path.
  • The path can’t be obtained from the POSTIT_ROOT env var.
pub fn remove() -> Result<()>

Deletes the config file.

Errors
  • The path can’t be obtained from the POSTIT_ROOT env var.
  • The file doesn’t exist at the parent path.
Panics
  • The parent can’t be obtained from the path.
pub fn list() -> Result<()>

Displays a list of the current config values.

Errors
  • The file doesn’t exist at the parent path (displays default config too).
  • The configuration can’t be loaded.
pub fn set(args: ConfigSet) -> Result<()>

Sets a value for the passed key.

Errors
  • The file doesn’t exist at the parent path.
  • There are no values provided.
  • The configuration can’t be loaded.
Source

impl Config

pub fn env() -> Result<String>

Returns the value of the POSTIT_ROOT environment variable, which must have a path structure.

Errors
  • The POSTIT_ROOT env var is not present or has not unicode characters.
pub fn config_file_name() -> String

Returns the name of the config file.

pub fn path_from_env() -> Result<PathBuf>

Returns the value of the POSTIT_ROOT environment variable, which must have a path structure.

Errors
  • The POSTIT_ROOT exists but is empty.
  • The value of POSTIT_ROOT contains not unicode characters.
  • The path from POSTIT_ROOT is relative.
pub fn home() -> PathBuf

Returns the HOME path of the currently used OS, which will be the default path of postit’s generated files.

Panics
  • The user’s home directory can’t be located.
pub fn default_config_parent() -> PathBuf

Returns the default path of postit’s config file.

pub fn path() -> Result<PathBuf>

Returns the path of the config file in the POSTIT_ROOT env var.

Errors
  • The path can’t be obtained from the POSTIT_ROOT env var.
pub fn _check_path_exists() -> Result<()>

Checks if the path exists.

Errors
  • The file doesn’t exist at the parent path.
Panics
  • The parent can’t be obtained from the path.
pub fn get_parent_path() -> Result<PathBuf>

Obtains the path for the File instance, which is the parent path that the stores the config file.

Errors
  • The path can’t be obtained.
Panics
  • The parent path can’t be extracted from the configuration path.
pub fn build_path<T: AsRef<Path>>(path: T) -> Result<PathBuf>

Returns the path constructed from pushing the file persister path to the parent path (the one where .postit.toml is stored).

Errors
  • The path passed doesn’t have a parent path.
Panics
  • If the path can’t be converted to str.
  • If the parent path can’t be converted to str.
pub fn load() -> Result<Self>

Loads the config from a file or creates it if it doesn’t exist.

Errors
  • The config file can’t be loaded.
  • The config file can’t be read.
pub fn save(&self) -> Result<()>

Saves the config instance to a file.

Errors
  • The config path can’t be obtained.
  • The config file can’t be created.
  • The config can’t be formatted to TOML.
  • The config file can’t be saved.