pub struct Orm { /* private fields */ }Expand description
Abstraction of database actions, used to manage a Todo structure.
Implementations
Sourceimpl Orm
impl Orm
Sourcepub const fn new(db: Box<dyn DbPersister>) -> Self
pub const fn new(db: Box<dyn DbPersister>) -> Self
Constructor of the Orm struct, which controls instances of structs
that implement the DbPersister trait.
Sourcepub fn is_sqlite(conn: &str) -> bool
pub fn is_sqlite(conn: &str) -> bool
Checks if the passed connection string has an Sqlite format.
Panics
- The extension can’t be converted to
&str.
Sourcepub fn get_persister<T: AsRef<str>>(conn: T) -> Result<Box<dyn DbPersister>>
pub fn get_persister<T: AsRef<str>>(conn: T) -> Result<Box<dyn DbPersister>>
Returns a struct that implements the DbPersister trait based on
a connection string.
Errors
- If the persister can’t be obtained.
- If the connection string is empty.