pub struct Config {
pub persister: String,
pub force_drop: bool,
pub force_copy: bool,
pub drop_after_copy: bool,
}Expand description
Contains the configuration used while running postit.
If the configuration file doesn’t exist, it uses the default values defined in the Default trait implementation.
Fields
persister: StringDefines where tasks are stored. It can be the path to a file or a database connection string (including protocol).
force_drop: boolIf true, allows dropping tasks without them being checked.
force_copy: boolIf true, allows overwriting files if they already exist.
drop_after_copy: boolIf true, drops the old file after copying its contents to the new file.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn manage(subcommand: Config) -> Result<()>
pub fn manage(subcommand: Config) -> Result<()>
Manages the .postit.toml file using a ConfigSubcommand instance.
Errors
- Any error while doing operations on a the configuration file.
Sourcepub fn init() -> Result<()>
pub fn init() -> Result<()>
Creates the config file from the default values.
Errors
- The path can’t be obtained.
- The config file already exists at the used path.
Sourcepub fn print_path() -> Result<()>
pub fn print_path() -> Result<()>
Prints the path of the config file.
Errors
- The file doesn’t exist at the parent path.
- The path can’t be obtained from the
POSTIT_ROOTenv var.
Sourceimpl Config
impl Config
Sourcepub fn env() -> Result<String>
pub fn env() -> Result<String>
Returns the value of the POSTIT_ROOT environment variable, which must
have a path structure.
Errors
- The
POSTIT_ROOTenv var is not present or has not unicode characters.
Sourcepub fn config_file_name() -> String
pub fn config_file_name() -> String
Returns the name of the config file.
Sourcepub fn path_from_env() -> Result<PathBuf>
pub fn path_from_env() -> Result<PathBuf>
Returns the value of the POSTIT_ROOT environment variable, which must
have a path structure.
Errors
- The
POSTIT_ROOTexists but is empty. - The value of
POSTIT_ROOTcontains not unicode characters. - The path from
POSTIT_ROOTis relative.
Sourcepub fn home() -> PathBuf
pub fn home() -> PathBuf
Returns the HOME path of the currently used OS, which will be the default path of postit’s generated files.
Panics
- The user’s home directory can’t be located.
Sourcepub fn default_config_parent() -> PathBuf
pub fn default_config_parent() -> PathBuf
Returns the default path of postit’s config file.
Sourcepub fn path() -> Result<PathBuf>
pub fn path() -> Result<PathBuf>
Returns the path of the config file in the POSTIT_ROOT env var.
Errors
- The path can’t be obtained from the
POSTIT_ROOTenv var.
Sourcepub fn _check_path_exists() -> Result<()>
pub fn _check_path_exists() -> Result<()>
Sourcepub fn get_parent_path() -> Result<PathBuf>
pub fn get_parent_path() -> Result<PathBuf>